@@ -20,7 +20,9 @@ tcsh prompt: set prompt='[SL %~]$ '
 If called with the -s option, it will parse <logfilename> as if it was a raw file and
 remove all escape characters, printing to standard out. 
 
-Much code borrowed from
+Much of the terminal-related logic comes from example code posted 
+to comp.lang.python by Donn Cave. Used here with his permission.
+For the original post, see: 
 http://groups.google.com/group/comp.lang.python/msg/de40b36c6f0c53cc
 """
 
@@ -340,8 +342,7 @@ class Logger:
 # this is used to identify the data directory
 re_prompt = re.compile(r'(.*)^\[SL (.*)\]\$ $', re.MULTILINE | re.DOTALL | re.IGNORECASE)
 mac_prompt = re.compile(re.compile(r'(?:.*)\[SL (.*)\](.*)(\$)?',re.MULTILINE | re.DOTALL | re.IGNORECASE))
-linux_prompt = re.compile(r'(?:.*)\[SL (.*)\]\$')
-
+linux_prompt = re.compile(r'(?:.*)\[SL (.*)\]\$',re.MULTILINE | re.DOTALL | re.IGNORECASE)
 
 def is_enter(buf):
     # Check if buffer consists entirely of \n or \r
@@ -502,6 +503,8 @@ class ShellOutputState:
     def input_from_shell(self,buf):
         # Check if it's the prompt
         m = re_prompt.match(buf)
+        mac = mac_prompt.match(buf)
+        linux = linux_prompt.match(buf)
         if m is not None:
             # It's the prompt!
             self.saw_prompt = True
@@ -515,6 +518,12 @@ class ShellOutputState:
                    self.logger.cwd = os.path.expanduser(m.group(1))
                    self.logger.write('</result>\n</cli-logger-entry>\n\n' % time.time())
                    self.seen_prompt = True
+        elif mac is not None:
+               self.logger.cwd = os.path.expanduser(mac.group(1))
+               self.logger.write("]]></result>\n</cli-logger-entry>\n\n")
+        elif linux is not None:
+               self.logger.cwd = os.path.expanduser(linux.group(1))
+               self.logger.write("]]></result>\n</cli-logger-entry>\n\n")
         else:
             self.write_output_to_log(buf)
 
@@ -533,6 +542,10 @@ class ShellOutputState:
             return self
 
 class ShellOutputNoOutputState(ShellOutputState):
+    """
+
+    TODO: This is a dead state, which is clearly incorrect.
+    """
     def write_output_to_log(self,buf):
         pass
 
